// Copyright 2025 Specter Ops, Inc.
//
// Licensed under the Apache License, Version 2.0
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// SPDX-License-Identifier: Apache-2.0

//go:build serial_integration
// +build serial_integration

package v2

import (
	"context"
	"testing"

	"github.com/specterops/bloodhound/cmd/api/src/test/integration"
	"github.com/specterops/bloodhound/packages/go/graphschema"
	"github.com/stretchr/testify/require"
)

func Test_ListKinds(t *testing.T) {
	var (
		testCtx = context.Background()
		graphDB = integration.OpenGraphDB(t, graphschema.DefaultGraphSchema())
	)
	defer graphDB.Close(testCtx)

	kinds, err := graphDB.FetchKinds(testCtx)
	require.NoError(t, err)
	require.True(t, len(kinds) > 0)
}
